// src/index.ts
import * as React from "react";
import { assign, createMachine } from "xstate";
import { useMachine } from "@xstate/react";

// src/utils.ts
function isEqual(array1, array2) {
  return JSON.stringify(array1) === JSON.stringify(array2);
}
function takeRight(array, n) {
  if (n < 1)
    return [];
  return array.slice(-1 * n);
}

// src/index.ts
var initialContext = {
  cheatCodeKeys: void 0,
  typedKeys: []
};
var cheatCodeMachine = createMachine({
  context: initialContext,
  tsTypes: {},
  schema: {
    context: {},
    events: {}
  },
  id: "cheatCodeMachine",
  initial: "disabled",
  states: {
    disabled: {
      initial: "idle",
      states: {
        idle: {
          always: {
            actions: "resetTypedKeys",
            cond: "cheatCodeEntered",
            target: "#cheatCodeMachine.enabled"
          },
          on: {
            keydown: {
              actions: "record",
              target: "#cheatCodeMachine.disabled.recording"
            }
          }
        },
        recording: {
          after: {
            doneTyping: {
              actions: "resetTypedKeys",
              target: "#cheatCodeMachine.disabled.idle"
            }
          },
          always: {
            actions: "resetTypedKeys",
            cond: "cheatCodeEntered",
            target: "#cheatCodeMachine.enabled"
          },
          on: {
            keydown: {
              actions: "record",
              target: "#cheatCodeMachine.disabled.recording"
            }
          }
        }
      }
    },
    enabled: {
      initial: "idle",
      states: {
        idle: {
          always: {
            actions: "resetTypedKeys",
            cond: "cheatCodeEntered",
            target: "#cheatCodeMachine.disabled"
          },
          on: {
            keydown: {
              actions: "record",
              target: "#cheatCodeMachine.enabled.recording"
            }
          }
        },
        recording: {
          after: {
            doneTyping: {
              actions: "resetTypedKeys",
              target: "#cheatCodeMachine.enabled.idle"
            }
          },
          always: {
            actions: "resetTypedKeys",
            cond: "cheatCodeEntered",
            target: "#cheatCodeMachine.disabled"
          },
          on: {
            keydown: {
              actions: "record",
              target: "#cheatCodeMachine.enabled.recording"
            }
          }
        }
      }
    }
  }
}, {
  actions: {
    record: assign({
      typedKeys: (context, event) => [...context.typedKeys, event.key]
    }),
    resetTypedKeys: assign({
      typedKeys: initialContext.typedKeys
    })
  },
  delays: {
    doneTyping: 2e3
  },
  guards: {
    cheatCodeEntered: (context) => Array.isArray(context.cheatCodeKeys) && isEqual(takeRight(context.typedKeys, context.cheatCodeKeys.length), context.cheatCodeKeys)
  }
});
function useCheatCode(cheatCodeKeys) {
  const machineOpts = React.useMemo(() => ({
    context: { cheatCodeKeys }
  }), [cheatCodeKeys]);
  const [state, send] = useMachine(cheatCodeMachine, machineOpts);
  React.useEffect(() => {
    const handleKeydownEvent = (event) => {
      send(event);
    };
    window.addEventListener("keydown", handleKeydownEvent);
    return () => {
      window.removeEventListener("keydown", handleKeydownEvent);
    };
  }, [send]);
  return state.matches("enabled");
}
var useSecretCode = useCheatCode;
export {
  useCheatCode,
  useSecretCode
};
//# sourceMappingURL=index.mjs.map